==> haskell-servant-server-0.13.0.1-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-46OHT4LJIDt3H13bP7SFTz
key: servant-server-0.13.0.1-46OHT4LJIDt3H13bP7SFTz
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: db5ef4945a1414f7b29f6f1e8c62a346
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-46OHT4LJIDt3H13bP7SFTz
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-6jNGRs1c7xvhs2BOgR9ea
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    http-api-data-0.3.8.1-JiVkHmd2TcnLSkEbBfULk3
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI
    network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx
    wai-app-static-3.1.6.2-59H7bKiVzEb64zj8OHi8D7
    warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             servant-0.13.0.1-6jNGRs1c7xvhs2BOgR9ea=bff2f2f3c0087d34db9e0334fb49b62d
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             http-api-data-0.3.8.1-JiVkHmd2TcnLSkEbBfULk3=f34dab935653217b03960958d60a6746
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=03145435aceae6e5208d7a1b612976f3
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc=8d6025dec3e5dd700b855b90a1ac9ead
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx=a10b0b451ac20f27f6160db52b013dec
             wai-app-static-3.1.6.2-59H7bKiVzEb64zj8OHi8D7=06811deb95d12aa6dfed234142bdee12
             warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A=6e2c18e816108018f85e88f517ed2b28
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.13.0.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-server
version: 0.13.0.1
id: servant-server-0.13.0.1-JDpDVheW2miCliUJzOpfTK
key: servant-server-0.13.0.1-JDpDVheW2miCliUJzOpfTK
license: BSD-3-Clause
copyright: 2014-2016 Zalora South East Asia Pte Ltd, Servant Contributors
maintainer: haskell-servant-maintainers@googlegroups.com
author: Servant Contributors
homepage: http://haskell-servant.readthedocs.org/
synopsis: A family of combinators for defining webservices APIs and serving them
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://haskell-servant.readthedocs.org/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>
category: Servant, Web
abi: 32b9d49ef29e911506b6e1ad0def335b
exposed: True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Internal Servant.Server.Internal.BasicAuth
    Servant.Server.Internal.Context Servant.Server.Internal.Handler
    Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServantErr Servant.Utils.StaticFiles
import-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/servant-server-0.13.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/servant-server-0.13.0.1
hs-libraries: HSservant-server-0.13.0.1-JDpDVheW2miCliUJzOpfTK
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 mtl-2.2.2
    text-1.2.3.0 transformers-0.5.5.0 filepath-1.4.2
    servant-0.13.0.1-6jNGRs1c7xvhs2BOgR9ea
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    http-api-data-0.3.8.1-JiVkHmd2TcnLSkEbBfULk3
    http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI
    network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh
    wai-app-static-3.1.6.2-4hKJzHst5cK3TmRgQavXy3
    warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             servant-0.13.0.1-6jNGRs1c7xvhs2BOgR9ea=bff2f2f3c0087d34db9e0334fb49b62d
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             http-api-data-0.3.8.1-JiVkHmd2TcnLSkEbBfULk3=f34dab935653217b03960958d60a6746
             http-media-0.7.1.2-2agRPy8NKmR6zMh072NVzf=3b8ff7a7eec0b45994664ca667110b69
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK=94d8930bfafd62e59b581d22ac71f05d
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=03145435aceae6e5208d7a1b612976f3
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             transformers-base-0.4.5.2-8WC7bFFnNGCEYZMgQnFBlc=8d6025dec3e5dd700b855b90a1ac9ead
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh=3c531a9c9dceb5cf3884617d81bc336d
             wai-app-static-3.1.6.2-4hKJzHst5cK3TmRgQavXy3=d329f9cdbb78688f1f84a9c53effc472
             warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W=1d9baf1f171c173416edccd3cf032c07
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
haddock-interfaces: /usr/share/doc/haskell-servant-server/html/servant-server.haddock
haddock-html: /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
